@@ -1,7 +1,16 @@
+# Copyright (c) 2014, Facebook, Inc.  All rights reserved.
+#
+# This source code is licensed under the BSD-style license found in the
+# LICENSE file in the root directory of this source tree. An additional grant
+# of patent rights can be found in the PATENTS file in the same directory.
+#
+"""This module contains tornado-related helper tasks and classes."""
 from __future__ import absolute_import
 
-from ..vtask import VTask, SkipTask
-from ..sparts import option, counter  #, samples, SampleType
+from six import itervalues
+from sparts.counters import counter  #, samples, SampleType
+from sparts.sparts import option
+from sparts.vtask import VTask, SkipTask
 
 import tornado.ioloop
 import tornado.web
@@ -13,6 +22,7 @@ import os
 
 
 class TornadoIOLoopTask(VTask):
+    """Configure and run the Tornado IO Loop in a sparts task"""
     OPT_PREFIX = 'tornado'
 
     def initTask(self):
@@ -36,6 +46,11 @@ class TornadoIOLoopTask(VTask):
 
 
 class TornadoTask(VTask):
+    """Base class for tasks that require the tornado IO Loop.
+    
+    Implicitly configures the tornado IO Loop task as a dependency.
+    
+    The ioloop can be accessed via `self.ioloop`"""
     DEPS = [TornadoIOLoopTask]
 
     def initTask(self):
@@ -48,6 +63,10 @@ class TornadoTask(VTask):
 
 
 class TornadoHTTPTask(TornadoTask):
+    """A loopless task that implements an HTTP server using Tornado.
+    
+    It is loopless because it depends on tornado's separate IOLoop task.  You
+    will need to subclass this to do something more useful."""
     LOOPLESS = True
     OPT_PREFIX = 'http'
     DEFAULT_PORT = 0
@@ -68,6 +87,12 @@ class TornadoHTTPTask(TornadoTask):
     group = option(name='sock-group', metavar='GROUP', default='',
                    help='Group to create unix files as [%(default)s]')
 
+    def getApplicationConfig(self):
+        """Override this to register custom handlers / routes."""
+        return [
+            ('/', HelloWorldHandler),
+        ]
+
     def initTask(self):
         super(TornadoHTTPTask, self).initTask()
 
@@ -85,10 +110,10 @@ class TornadoHTTPTask(TornadoTask):
                 "Do not specify port *and* sock (%s, %s)" % \
                 (self.port, self.DEFAULT_PORT)
 
-            gid, mode = -1, 0600
+            gid, mode = -1, 0o600
             if self.group != '':
                 e = grp.getgrnam(self.group)
-                gid, mode = e.gr_gid, 0660
+                gid, mode = e.gr_gid, 0o660
 
             sock = tornado.netutil.bind_unix_socket(self.sock, mode=mode)
             if gid != -1:
@@ -98,7 +123,7 @@ class TornadoHTTPTask(TornadoTask):
             self.server.listen(self.port, self.host)
 
         self.bound_addrs = []
-        for sock in self.server._sockets.itervalues():
+        for sock in itervalues(self.server._sockets):
             sockaddr = sock.getsockname()
             self.bound_addrs.append(sockaddr)
             self.logger.info("%s Server Started on %s (port %s)",
@@ -119,11 +144,8 @@ class TornadoHTTPTask(TornadoTask):
         super(TornadoHTTPTask, self).stop()
         self.server.stop()
 
-    def getApplicationConfig(self):
-        return [
-            ('/', HelloWorldHandler),
-        ]
 
 class HelloWorldHandler(tornado.web.RequestHandler):
+    """A sample twisted web handler for use in the default http server task"""
     def get(self):
         self.write("Hello, world")
